@@ -20,13 +20,13 @@ from ..models import (
 
 @skipUnlessDBFeature('supports_nullable_unique_constraints')
 class TestNullableUniqueColumn(TestCase):
-    def test_multiple_nulls(self):
+    def test_type_change(self):
         # Issue https://github.com/ESSolutions/django-mssql-backend/issues/45 (case 1)
         # After field `x` has had its type changed, the filtered UNIQUE INDEX which is
         # implementing the nullable unique constraint should still be correctly in place
         # i.e. allowing multiple NULLs but still enforcing uniqueness of non-NULLs
 
-        # Allowed
+        # Allowed (NULL != NULL)
         TestUniqueNullableModel.objects.create(x=None, test_field='randomness')
         TestUniqueNullableModel.objects.create(x=None, test_field='doesntmatter')
 
@@ -35,6 +35,22 @@ class TestNullableUniqueColumn(TestCase):
         with self.assertRaises(IntegrityError):
             TestUniqueNullableModel.objects.create(x="foo", test_field='nonsense')
 
+    def test_rename(self):
+        # Rename of a column which is both nullable & unique. Test that
+        # the constraint-enforcing unique index survived this migration
+        # Related to both:
+        # Issue https://github.com/microsoft/mssql-django/issues/67
+        # Issue https://github.com/microsoft/mssql-django/issues/14
+
+        # Allowed (NULL != NULL)
+        TestUniqueNullableModel.objects.create(y_renamed=None, test_field='something')
+        TestUniqueNullableModel.objects.create(y_renamed=None, test_field='anything')
+
+        # Disallowed
+        TestUniqueNullableModel.objects.create(y_renamed=42, test_field='nonimportant')
+        with self.assertRaises(IntegrityError):
+            TestUniqueNullableModel.objects.create(y_renamed=42, test_field='whocares')
+
 
 @skipUnlessDBFeature('supports_partially_nullable_unique_constraints')
 class TestPartiallyNullableUniqueTogether(TestCase):
@@ -76,6 +92,7 @@ class TestRenameManyToManyField(TestCase):
         other2 = M2MOtherModel.objects.create(name='2')
         thing1.others_renamed.set([other1, other2])
         # Check that the unique_together on the through table is still enforced
+        # (created by create_many_to_many_intermediary_model)
         ThroughModel = TestRenameManyToManyFieldModel.others_renamed.through
         with self.assertRaises(IntegrityError, msg='Through model fails to enforce uniqueness after m2m rename'):
             # This should fail due to the unique_together because (thing1, other1) is already in the through table
